@@ -115,6 +115,7 @@ use AutoLoader;
 	CDF_INT4
 	CDF_INT8
 	CDF_INTERNAL_ERROR
+	CDF_LEAPSECONDLASTUPDATED_
 	CDF_MAJORITY_
 	CDF_MAXREC_
 	CDF_MAX_DIMS
@@ -728,6 +729,7 @@ FCN: {
 		    $item == &zVAR_NUMallocRECS_ ||
 		    $item == &zVAR_NUMDIMS_ || $item == &zVAR_NUMELEMS_ || 
 		    $item == &zVAR_NUMRECS_ ||
+		    $item == CDF_LEAPSECONDLASTUPDATED_ ||
 		    $item == &zVAR_RECVARY_ || $item == &zVAR_SPARSERECORDS_ ||
 		    $item == &zVARs_MAXREC_ || $item == &CDF_CHECKSUM_) {
 			my $LongRef = shift;
@@ -865,6 +867,7 @@ FCN: {
 		         $item == &zVAR_INITIALRECS_ || 
 			 $item == &zVAR_RECVARY_ ||
 			 $item == &zVAR_SPARSERECORDS_ || 
+			 $item == CDF_LEAPSECONDLASTUPDATED_ ||
 			 $item == &CDF_CHECKSUM_) {
 			my $Long = shift;
 			$status = CDFlibl($operation, $item, $Long);
