@@ -45,8 +45,8 @@
 use strict;
 use Math::BigInt;
 
-BEGIN { unshift @INC,'/home/cdf/PerlCDF35_1/blib/arch',
-                     '/home/cdf/PerlCDF35_1/blib/lib'; }
+BEGIN { unshift @INC,'/home/liu/PerlCDF36_4/blib/arch',
+                     '/home/liu/PerlCDF36_4/blib/lib'; }
 use CDF;
 
 my $N_DIMS = 2;
@@ -651,16 +651,19 @@ QuitCDF ("14a.1", $status) if ($status < CDF_OK) ;
 #############################################################################
 
 my ($version_out, $release_out, $increment_out, $subincrement_out, $CopyRightText);
+my $lastUpdated;
 $status = CDF::CDFlib (GET_, LIB_VERSION_, \$version_out,
 			     LIB_RELEASE_, \$release_out,
 			     LIB_INCREMENT_, \$increment_out,
 			     LIB_subINCREMENT_, \$subincrement_out,
 			     LIB_COPYRIGHT_, \$CopyRightText,
+			     CDF_LEAPSECONDLASTUPDATED_, \$lastUpdated,
 		       NULL_);
 QuitCDF ("15.0", $status) if ($status < CDF_OK) ;
 print "CDF Library Version $version_out, Release $release_out
 Increment $increment_out and subIncrement $subincrement_out
 Copyright: $CopyRightText\n";
+print "Leap second LastUpdated: $lastUpdated\n";
 
 #############################################################################
 # Inquire CDF.
